unit Main;

{$IFDEF CONDITIONALEXPRESSIONS}
{$IF RTLVersion >= 14.0}
{$DEFINE D6_UP}
{$IFEND}
{$ENDIF}

interface

uses Classes, Controls, Forms, StdCtrls, Dialogs;

type
  TMainForm = class(TForm)
    OpenBtn: TButton;
    ContactsLB: TListBox;
    AddBtn: TButton;
    EditBtn: TButton;
    DeleteBtn: TButton;
    OpenDialog1: TOpenDialog;
    procedure FormDestroy(Sender: TObject);
    procedure OpenBtnClick(Sender: TObject);
    procedure AddBtnClick(Sender: TObject);
    procedure EditBtnClick(Sender: TObject);
    procedure DeleteBtnClick(Sender: TObject);
    procedure ContactsLBClick(Sender: TObject);
  private
    procedure SetButtons;
  end;

var
  MainForm: TMainForm;

implementation

uses Windows, Registry, {$IFDEF D6_UP} Variants, {$ENDIF} WabObj, WabTags, Edit;

{$R *.dfm}

var
  WAB: TWABContacts;

function GetDefaultWABFileName: String;
begin
  Result := '';
  with TRegistry.Create do
   try
    RootKey := HKEY_CURRENT_USER;
    if OpenKey('\Software\Microsoft\Wab\WAB4\Wab File Name', False) then
     Result := ReadString('');
   finally
    Free;
   end;
end;

procedure TMainForm.FormDestroy(Sender: TObject);
begin
  WAB.Free;
  WAB := nil;
end;

procedure TMainForm.OpenBtnClick(Sender: TObject);
var
  I: Integer;
begin
  OpenDialog1.FileName := GetDefaultWABFileName;
  if OpenDialog1.Execute then
  begin
   WAB.Free;
   WAB := TWABContacts.Create(OpenDialog1.FileName);
   ContactsLB.Items.BeginUpdate;
   try
    ContactsLB.Items.Clear;
    for I := 0 to WAB.ContactCount - 1 do
     ContactsLB.Items.Add(WAB[I].PropByTag[PR_DISPLAY_NAME]);
   finally
    ContactsLB.Items.EndUpdate;
    SetButtons;
   end;
  end;
end;

procedure TMainForm.SetButtons;
begin
  AddBtn.Enabled := WAB <> nil;
  EditBtn.Enabled := ContactsLB.ItemIndex >= 0;
  DeleteBtn.Enabled := ContactsLB.ItemIndex >= 0;
end;

procedure TMainForm.AddBtnClick(Sender: TObject);
begin
  with EditForm do
  begin
   DisplayNameEd.Text := '';
   FirstNameEd.Text := '';
   LastNameEd.Text := '';
   MobileEd.Text := '';
   PhoneEd.Text := '';
   EmailEd.Text := '';
   HomePageEd.Text := '';
   HomeAddrStreetEd.Text := '';
   HomeAddrCityEd.Text := '';
   HomeAddrStateEd.Text := '';
   HomeAddrPostalEd.Text := '';
   HomeAddrContryEd.Text := '';
   CompanyEd.Text := '';
   ProfessionEd.Text := '';
   BusFaxEd.Text := '';
   BusPhoneEd.Text := '';
   BusHomePageEd.Text := '';
   BusAddrStreetEd.Text := '';
   BusAddrCityEd.Text := '';
   BusAddrStateEd.Text := '';
   BusAddrPostalEd.Text := '';
   BusAddrCountryEd.Text := '';
   if ShowModal = mrOK then
    with WAB.NewContact do
    begin
     PropByTag[PR_DISPLAY_NAME] := DisplayNameEd.Text;
     PropByTag[PR_GIVEN_NAME] := FirstNameEd.Text;
     PropByTag[PR_SURNAME] := LastNameEd.Text;
     PropByTag[PR_MOBILE_TELEPHONE_NUMBER] := MobileEd.Text;
     PropByTag[PR_HOME_TELEPHONE_NUMBER] := PhoneEd.Text;
     PropByTag[PR_EMAIL_ADDRESS] := EmailEd.Text;
     PropByTag[PR_PERSONAL_HOME_PAGE] := HomePageEd.Text;
     PropByTag[PR_HOME_ADDRESS_STREET] := HomeAddrStreetEd.Text;
     PropByTag[PR_HOME_ADDRESS_CITY] := HomeAddrCityEd.Text;
     PropByTag[PR_HOME_ADDRESS_STATE_OR_PROVINCE] := HomeAddrStateEd.Text;
     PropByTag[PR_HOME_ADDRESS_POSTAL_CODE] := HomeAddrPostalEd.Text;
     PropByTag[PR_HOME_ADDRESS_COUNTRY] := HomeAddrContryEd.Text;
     PropByTag[PR_COMPANY_NAME] := CompanyEd.Text;
     PropByTag[PR_PROFESSION] := ProfessionEd.Text;
     PropByTag[PR_BUSINESS_FAX_NUMBER] := BusFaxEd.Text;
     PropByTag[PR_BUSINESS_TELEPHONE_NUMBER] := BusPhoneEd.Text;
     PropByTag[PR_BUSINESS_HOME_PAGE] := BusHomePageEd.Text;
     PropByTag[PR_BUSINESS_ADDRESS_STREET] := BusAddrStreetEd.Text;
     PropByTag[PR_BUSINESS_ADDRESS_CITY] := BusAddrCityEd.Text;
     PropByTag[PR_BUSINESS_ADDRESS_STATE_OR_PROVINCE] := BusAddrStateEd.Text;
     PropByTag[PR_BUSINESS_ADDRESS_POSTAL_CODE] := BusAddrPostalEd.Text;
     PropByTag[PR_BUSINESS_ADDRESS_COUNTRY] := BusAddrCountryEd.Text;
     Save;
     ContactsLB.ItemIndex := ContactsLB.Items.Add(PropByTag[PR_DISPLAY_NAME]);
     SetButtons;
    end;
  end;
end;

procedure TMainForm.EditBtnClick(Sender: TObject);
begin
  with EditForm, WAB[ContactsLB.ItemIndex] do
  begin
   DisplayNameEd.Text := VarToStr(PropByTag[PR_DISPLAY_NAME]);
   FirstNameEd.Text := VarToStr(PropByTag[PR_GIVEN_NAME]);
   LastNameEd.Text := VarToStr(PropByTag[PR_SURNAME]);
   MobileEd.Text := VarToStr(PropByTag[PR_MOBILE_TELEPHONE_NUMBER]);
   PhoneEd.Text := VarToStr(PropByTag[PR_HOME_TELEPHONE_NUMBER]);
   EmailEd.Text := VarToStr(PropByTag[PR_EMAIL_ADDRESS]);
   HomePageEd.Text := VarToStr(PropByTag[PR_PERSONAL_HOME_PAGE]);
   HomeAddrStreetEd.Text := VarToStr(PropByTag[PR_HOME_ADDRESS_STREET]);
   HomeAddrCityEd.Text := VarToStr(PropByTag[PR_HOME_ADDRESS_CITY]);
   HomeAddrStateEd.Text := VarToStr(PropByTag[PR_HOME_ADDRESS_STATE_OR_PROVINCE]);
   HomeAddrPostalEd.Text := VarToStr(PropByTag[PR_HOME_ADDRESS_POSTAL_CODE]);
   HomeAddrContryEd.Text := VarToStr(PropByTag[PR_HOME_ADDRESS_COUNTRY]);
   CompanyEd.Text := VarToStr(PropByTag[PR_COMPANY_NAME]);
   ProfessionEd.Text := VarToStr(PropByTag[PR_PROFESSION]);
   BusFaxEd.Text := VarToStr(PropByTag[PR_BUSINESS_FAX_NUMBER]);
   BusPhoneEd.Text := VarToStr(PropByTag[PR_BUSINESS_TELEPHONE_NUMBER]);
   BusHomePageEd.Text := VarToStr(PropByTag[PR_BUSINESS_HOME_PAGE]);
   BusAddrStreetEd.Text := VarToStr(PropByTag[PR_BUSINESS_ADDRESS_STREET]);
   BusAddrCityEd.Text := VarToStr(PropByTag[PR_BUSINESS_ADDRESS_CITY]);
   BusAddrStateEd.Text := VarToStr(PropByTag[PR_BUSINESS_ADDRESS_STATE_OR_PROVINCE]);
   BusAddrPostalEd.Text := VarToStr(PropByTag[PR_BUSINESS_ADDRESS_POSTAL_CODE]);
   BusAddrCountryEd.Text := VarToStr(PropByTag[PR_BUSINESS_ADDRESS_COUNTRY]);
   if ShowModal = mrOK then
   begin
    PropByTag[PR_DISPLAY_NAME] := DisplayNameEd.Text;
    PropByTag[PR_GIVEN_NAME] := FirstNameEd.Text;
    PropByTag[PR_SURNAME] := LastNameEd.Text;
    PropByTag[PR_MOBILE_TELEPHONE_NUMBER] := MobileEd.Text;
    PropByTag[PR_HOME_TELEPHONE_NUMBER] := PhoneEd.Text;
    PropByTag[PR_EMAIL_ADDRESS] := EmailEd.Text;
    PropByTag[PR_PERSONAL_HOME_PAGE] := HomePageEd.Text;
    PropByTag[PR_HOME_ADDRESS_STREET] := HomeAddrStreetEd.Text;
    PropByTag[PR_HOME_ADDRESS_CITY] := HomeAddrCityEd.Text;
    PropByTag[PR_HOME_ADDRESS_STATE_OR_PROVINCE] := HomeAddrStateEd.Text;
    PropByTag[PR_HOME_ADDRESS_POSTAL_CODE] := HomeAddrPostalEd.Text;
    PropByTag[PR_HOME_ADDRESS_COUNTRY] := HomeAddrContryEd.Text;
    PropByTag[PR_COMPANY_NAME] := CompanyEd.Text;
    PropByTag[PR_PROFESSION] := ProfessionEd.Text;
    PropByTag[PR_BUSINESS_FAX_NUMBER] := BusFaxEd.Text;
    PropByTag[PR_BUSINESS_TELEPHONE_NUMBER] := BusPhoneEd.Text;
    PropByTag[PR_BUSINESS_HOME_PAGE] := BusHomePageEd.Text;
    PropByTag[PR_BUSINESS_ADDRESS_STREET] := BusAddrStreetEd.Text;
    PropByTag[PR_BUSINESS_ADDRESS_CITY] := BusAddrCityEd.Text;
    PropByTag[PR_BUSINESS_ADDRESS_STATE_OR_PROVINCE] := BusAddrStateEd.Text;
    PropByTag[PR_BUSINESS_ADDRESS_POSTAL_CODE] := BusAddrPostalEd.Text;
    PropByTag[PR_BUSINESS_ADDRESS_COUNTRY] := BusAddrCountryEd.Text;
    Save;
    ContactsLB.Items[ContactsLB.ItemIndex] := PropByTag[PR_DISPLAY_NAME];
    SetButtons;
   end;
  end;
end;

procedure TMainForm.DeleteBtnClick(Sender: TObject);
begin
  WAB.Delete(ContactsLB.ItemIndex);
  ContactsLB.Items.Delete(ContactsLB.ItemIndex);
  SetButtons;
end;

procedure TMainForm.ContactsLBClick(Sender: TObject);
begin
  SetButtons;
end;

end.
